from mms.kms_handler import KmsService


if __name__ == '__main__':

    '''
    
    plain = KmsService.decrypt('v110-4853-facebook-marketing','europe-west4','data-access','data-access-facebook',
                               b'\n$\x00\xe5Y\xc4\x7f@\xbe\x89\x0e\x1ej\xc6\xe8F4\x92\xb7\x82\xe0/\x98\x07\x06\xa4h\x04w\xd9\xfa~\x9c\x152/\xcc\x1a\x12\x81\x02\x00\xd9\xdf ^\xb7\xb2\x05v\xe8\xfah\xfd\xc4\xc9\xf6\xe0\xa4\xa3U\xe6\x17YRk&\xfa\xa7\xed\x8c\xe0\x18\xf2a|J\xe7\xc8\x11\xb4o\x80\x9e[\xc2\xf0\xf5a%\xa8{Cc\xa2\r\xccwYr\xd0F\xeb?\xd0\x19o\r\xf3D|9y\xac\x1c\xf7`k\xfd\xfb\xab<\x046O\xf7\x9c\xe6\x9eD\xd0\x83\xf2\xb3\xe7\x91b\t7g7\xa2\xca}q\xf2s\xed\xe7\xec\x8al^\xb0\x03\x87n\x89\x8a\x1e~s,y9\xad\xeds\x19`\xab\xcf\xb4\x15\x93\xfe\x89\xcc\x1d)n\xf3?U\x1c\x18\xd8u\xe7\xd4J(H:\xdfg\xb9\x18\x82\xcc\xb2Y\x07F\x0fH"\xb8q\xc3k;p\xc1\xa3]\xdcm\xdd\xd7\xee\xe7a\xe7\x11^\x8a\xbf\xd2\xd9\xa1\x85zK`\xd6l\x1f\x84\xf8\x0c\xe6\xbcN\xe98=\x9a:q\xc4\xe7\xe3\x98{\x0bNY\xef\xe1\xa8\xc3z[E\xd6\x10E\xdaW\\\x86,`Z\xc79I\xfc=?\xa9\x86\x8e\x04\xf5\xfc\xbc\x02\x16KEs\x08=m2}')

    print(plain)
    
    '''

    encr = KmsService.encrypt('v110-4853-facebook-marketing','europe-west4','data-access','data-access-facebook', b'this-is-shit')
    print(encr)

